@@ -76,7 +76,7 @@ OC.L10N.register(
     "%s has mentioned you in a comment on \"%s\"." : "%s vás zmínil(a) v komentáři k „%s“.",
     "{user} has mentioned you in a comment on {deck-card}." : "{user} vás zmínil(a) v komentáři na kartě {deck-card}.",
     "The board \"%s\" has been shared with you by %s." : "Uživatel %s vám nasdílel(a) tabuli „%s“.",
-    "{user} has shared {deck-board} with you." : "{user} s vámi sdílel(a) tabuli {deck-board}.",
+    "{user} has shared {deck-board} with you." : "{user} vám nasdílel(a) tabuli {deck-board}.",
     "Card comments" : "Komentáře v kartách",
     "%s on %s" : "%s na %s",
     "No data was provided to create an attachment." : "Nebyla poskytnuta žádná data pro vytvoření přílohy.",
@@ -130,6 +130,7 @@ OC.L10N.register(
     "Keep existing file" : "Ponechat existující soubor",
     "This board is read only" : "Tato tabule je pouze pro čtení",
     "Drop your files to upload" : "Přetáhněte sem soubory, které chcete nahrát",
+    "Add card" : "Přidat kartu",
     "Archived cards" : "Archivované karty",
     "Add list" : "Přidat seznam",
     "List name" : "Název seznamu",
@@ -173,7 +174,6 @@ OC.L10N.register(
     "Add a new list" : "Přidat nový sloupec",
     "Archive all cards" : "Archivovat všechny karty",
     "Delete list" : "Smazat seznam",
-    "Add card" : "Přidat kartu",
     "Archive all cards in this list" : "Archivovat všechny karty v tomto seznamu",
     "Add a new card" : "Přidat novou kartu",
     "Card name" : "Název karty",
