@@ -113,6 +113,7 @@ OC.L10N.register(
     "Overwrite file" : "Perrašyti failą",
     "Keep existing file" : "Palikti esamą failą",
     "This board is read only" : "Ši lenta yra tik skaitymui",
+    "Add card" : "Pridėti kortelę",
     "Archived cards" : "Archyvuotos kortelės",
     "Add list" : "Pridėti sąrašą",
     "List name" : "Sąrašo pavadinimas",
@@ -153,7 +154,6 @@ OC.L10N.register(
     "Add a new list" : "Pridėti naują sąrašą",
     "Archive all cards" : "Archyvuoti visas korteles",
     "Delete list" : "Ištrinti sąrašą",
-    "Add card" : "Pridėti kortelę",
     "Archive all cards in this list" : "Archyvuoti visas korteles šiame sąraše",
     "Add a new card" : "Pridėti naują kortelę",
     "Card name" : "Kortelės pavadinimas",
@@ -195,6 +195,7 @@ OC.L10N.register(
     "Edit description" : "Taisyti aprašą",
     "View description" : "Rodyti aprašą",
     "Add Attachment" : "Pridėti priedą",
+    "Write a description …" : "Parašykite aprašą…",
     "Choose attachment" : "Pasirinkite priedą",
     "(group)" : "(grupė)",
     "Assign to me" : "Priskirti sau",
@@ -214,9 +215,9 @@ OC.L10N.register(
     "Clone board" : "Dubliuoti lentą",
     "Unarchive board" : "Išarchyvuoti lentą",
     "Archive board" : "Archyvuoti lentą",
-    "Turn on due date reminders" : "Įjungti galutinio termino priminimus",
-    "Turn off due date reminders" : "Išjungti galutinio termino priminimus",
-    "Due date reminders" : "Galutinio termino priminimai",
+    "Turn on due date reminders" : "Įjungti priminimus apie galutinį terminą",
+    "Turn off due date reminders" : "Išjungti priminimus apie galutinį terminą",
+    "Due date reminders" : "Priminimai apie galutinį terminą",
     "All cards" : "Visos kortelės",
     "Assigned cards" : "Priskirtos kortelės",
     "No notifications" : "Pranešimų nėra",
