@@ -70,9 +70,15 @@ OC.L10N.register(
     "Upcoming cards" : "Nadchádzajúce karty",
     "Personal" : "Osobné",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Používateľ %s vám priradil kartu „%s“ na „%s“.",
+    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} vám priradil kartu {deck-card} na {deck-board}.",
     "The card \"%s\" on \"%s\" has reached its due date." : "Karta \"%s\" na nástenke \"%s\" dosiahla termín dokončenia.",
+    "The card {deck-card} on {deck-board} has reached its due date." : "Karta {deck-card} na {deck-board} dosiahla termín dokončenia.",
     "%s has mentioned you in a comment on \"%s\"." : "Používateľ %s vás zmienil v komentári ku „%s“.",
+    "{user} has mentioned you in a comment on {deck-card}." : "{user} vás spomenul v komentári v {deck-card}.",
     "The board \"%s\" has been shared with you by %s." : "Používateľ %s vám sprístupnil nástenku \"%s\".",
+    "{user} has shared {deck-board} with you." : "{user} zdieľa {deck-board} s vami.",
+    "Card comments" : "Komentáre karty",
+    "%s on %s" : "%s na %s",
     "No data was provided to create an attachment." : "Neboli poskytnuté dáta pre vytvorenie prílohy.",
     "Finished" : "Ukončené",
     "To review" : "Na posúdenie",
@@ -94,6 +100,9 @@ OC.L10N.register(
     "Could not write file to disk" : "Nepodarilo sa zapísať súbor na disk",
     "A PHP extension stopped the file upload" : "Rozšírenie PHP zastavilo nahrávanie súboru",
     "No file uploaded or file size exceeds maximum of %s" : "Nenahral sa žiadny súbor alebo jeho veľkosť presiahla %s",
+    "Card not found" : "Karta nebola nájdená",
+    "Path is already shared with this card" : "Cesta je už zdieľaná s touto kartou",
+    "Invalid date, date format must be YYYY-MM-DD" : "Neplatný dátum, formát musí byť v tvare YYYY-MM-DD",
     "Personal planning and team project organization" : "Osobné plánovanie a organizácia tímových projektov",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Karty sú nástroj zacielený na osobné alebo projektové plánovanie tímov v štýle Kanban integrovaný do Nextcloud.\n\n\n- 📥 Zadávajte a usporadúvajte svoje úlohy do kariet\n- 📄 Zapisujte si dodatočné poznámky\n- 🔖 Priraďujte štítky pre ešte lepšiu organizáciu\n- 👥 Zdieľajte so svojim tímom, priateľmi alebo rodinou\n- 🚀 Dostaňte svoj projekt pod kontrolu",
     "Card details" : "Podrobnosti o karte",
@@ -101,9 +110,16 @@ OC.L10N.register(
     "Select the board to link to a project" : "Vybrať nástenku na vytvorenie odkazu ku projektu",
     "Search by board title" : "Vyhľadávanie podľa názvu nástenky",
     "Select board" : "Vybrať nástenku",
+    "Create a new card" : "Vytvoriť novú kartu",
     "Select a board" : "Vyberte nástenku",
     "Select a list" : "Vybrať zoznam",
+    "Card title" : "Meno karty",
     "Cancel" : "Zrušiť",
+    "Creating the new card …" : "Vytváram novú kartu ...",
+    "Card \"{card}\" was added to \"{board}\"" : "Karta \"{card}\" bola pridaná na \"{board}\"",
+    "Open card" : "Otvoriť kartu",
+    "Close" : "Zatvoriť",
+    "Create card" : "Vytvoriť kartu",
     "Select a card" : "Vyberte kartu",
     "Select the card to link to a project" : "Vyberte kartu, ktorú chcete prepojiť s projektom",
     "Link to card" : "Prepojiť s kartou",
@@ -114,6 +130,7 @@ OC.L10N.register(
     "Keep existing file" : "Ponechať existujúci súbor",
     "This board is read only" : "Táto nástenka je iba na čítanie",
     "Drop your files to upload" : "Pretiahnite sem súbory, ktoré chcete nahrať",
+    "Add card" : "Pridať kartu",
     "Archived cards" : "Archivované karty",
     "Add list" : "Pridať zoznam",
     "List name" : "Názov zoznamu",
@@ -157,7 +174,6 @@ OC.L10N.register(
     "Add a new list" : "Pridať nový zoznam",
     "Archive all cards" : "Archivovať všetky karty",
     "Delete list" : "Vymazať zoznam",
-    "Add card" : "Pridať kartu",
     "Archive all cards in this list" : "Archivovať všetky karty v tomto zozname",
     "Add a new card" : "Pridať novú kartu",
     "Card name" : "Názov karty",
@@ -167,9 +183,15 @@ OC.L10N.register(
     "title and color value must be provided" : "je potrebné zadať nadpis a vybrať farbu",
     "Board name" : "Názov nástenky",
     "Members" : "Členovia",
+    "Upload new files" : "Nahrať nové súbory",
+    "Share from Files" : "Zdieľať zo Súborov",
     "Add this attachment" : "Pridať túto prílohu",
+    "Show in Files" : "Zobraziť v Súboroch",
+    "Unshare file" : "Nezdieľať súbor",
     "Delete Attachment" : "Odstrániť prílohu",
     "Restore Attachment" : "Obnoviť prílohu",
+    "File to share" : "Súbor na zdieľanie",
+    "Invalid path selected" : "Bola vybraná neplatná cesta",
     "Open in sidebar view" : "Otvoriť v zobrazení v bočnom paneli",
     "Open in bigger view" : "Otvoriť vo väčšom zobrazení",
     "Attachments" : "Prílohy",
@@ -178,6 +200,7 @@ OC.L10N.register(
     "Created" : "Vytvorené",
     "The title cannot be empty." : "Nadpis nemôže byť prázdny.",
     "No comments yet. Begin the discussion!" : "Zatiaľ bez komentárov. Začnite diskusiu!",
+    "Failed to load comments" : "Nepodarilo sa načítať komentáre",
     "Assign a tag to this card…" : "Tejto karte priradiť štítok…",
     "Assign to users" : "Priradiť používateľom",
     "Assign to users/groups/circles" : "Priradiť používateľom/skupinám/okruhom",
@@ -190,6 +213,7 @@ OC.L10N.register(
     "The comment cannot be empty." : "Komentár nemôže byť prázdny.",
     "The comment cannot be longer than 1000 characters." : "Komentár nemôže byť dlhší ako 1000 znakov.",
     "In reply to" : "Odpoveď na",
+    "Cancel reply" : "Zrušiť odpoveď",
     "Reply" : "Odpoveď",
     "Update" : "Aktualizovať",
     "Description" : "Popis",
@@ -202,6 +226,7 @@ OC.L10N.register(
     "Write a description …" : "Napíšte popis...",
     "Choose attachment" : "Vybrať prílohu",
     "(group)" : "(skupina)",
+    "{count} comments, {unread} unread" : "{count} komentárov, {unread} neprečítaných",
     "Assign to me" : "Priradiť mne",
     "Unassign myself" : "Zrušiť priradenie mne",
     "Move card" : "Presunúť kartu",
@@ -214,6 +239,7 @@ OC.L10N.register(
     "All boards" : "Všetky nástenky",
     "Archived boards" : "Archivované nástenky",
     "Shared with you" : "Vám sprístupnené",
+    "Use bigger card view" : "Použiť väčšie zobrazenie karty",
     "Show boards in calendar/tasks" : "Zobrazovať nástenky v kalendári/úlohách",
     "Limit deck usage of groups" : "Obmedziť použitie Deck na skupiny",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Obmedzenie Násteniek bráni používateľom, ktorí nie sú súčasťou týchto skupín, aby si vytvárali vlastné nástenky. Môžu však stále pracovať na nástenkách, ktoré im niekto sprístupní.",
@@ -240,11 +266,20 @@ OC.L10N.register(
     "Tomorrow" : "Zajtra",
     "This week" : "Tento týždeň",
     "No due" : "Žiadny termín dokončenia",
+    "Search for {searchQuery} in all boards" : "Vyhľadať {searchQuery} na všetkých plochách",
+    "No results found" : "Neboli nájdené žiadne výsledky",
     "No upcoming cards" : "Žiadne nadchádzajúce karty",
     "upcoming cards" : "nadchádzajúce karty",
     "Link to a board" : "Odkaz na nástenku",
     "Link to a card" : "Prepojiť s kartou",
+    "Create a card" : "Vytvoriť kartu",
+    "Message from {author} in {conversationName}" : "Správa od {author} v {conversationName}",
     "Something went wrong" : "Niečo sa pokazilo",
-    "Maximum file size of {size} exceeded" : "Bola prekročená maximálna veľkosť súboru {size}"
+    "Failed to upload {name}" : "Zlyhalo nahrávanie {name}",
+    "Maximum file size of {size} exceeded" : "Bola prekročená maximálna veľkosť súboru {size}",
+    "Error creating the share" : "Chyba pri vytváraní zdieľania",
+    "Share with a Deck card" : "Zdieľať s kartou Deck",
+    "Share {file} with a Deck card" : "Zdieľať {file} s kartou Deck",
+    "Share" : "Zdieľať"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
